aboutsummaryrefslogtreecommitdiffstats
path: root/src/google/protobuf/stubs/once_unittest.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/google/protobuf/stubs/once_unittest.cc')
-rw-r--r--src/google/protobuf/stubs/once_unittest.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/google/protobuf/stubs/once_unittest.cc b/src/google/protobuf/stubs/once_unittest.cc
index 86e0647..b8f86a0 100644
--- a/src/google/protobuf/stubs/once_unittest.cc
+++ b/src/google/protobuf/stubs/once_unittest.cc
@@ -52,10 +52,10 @@ class OnceInitTest : public testing::Test {
current_test_ = this;
}
// Since GoogleOnceType is only allowed to be allocated in static storage,
// each test must use a different pair of GoogleOnceType objects which it
// must declare itself.
- void SetOnces(GoogleOnceType* once, GoogleOnceType* recursive_once) {
+ void SetOnces(ProtobufOnceType* once, ProtobufOnceType* recursive_once) {
once_ = once;
recursive_once_ = recursive_once;
}
@@ -155,8 +155,8 @@ class OnceInitTest : public testing::Test {
Mutex mutex_;
Mutex init_blocker_;
State state_;
- GoogleOnceType* once_;
- GoogleOnceType* recursive_once_;
+ ProtobufOnceType* once_;
+ ProtobufOnceType* recursive_once_;
void Init() {
MutexLock lock(&mutex_);
@@ -52,10 +52,10 @@ class OnceInitTest : public testing::Test {
current_test_ = this;
}
- // Since GoogleOnceType is only allowed to be allocated in static storage,
- // each test must use a different pair of GoogleOnceType objects which it
+ // Since ProtobufOnceType is only allowed to be allocated in static storage,
+ // each test must use a different pair of ProtobufOnceType objects which it
// must declare itself.